==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/transfer_server/TransferServerWorkflowDetailsOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.transfer_server;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.951Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.transferServer.TransferServerWorkflowDetailsOutputReference")
public class TransferServerWorkflowDetailsOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected TransferServerWorkflowDetailsOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TransferServerWorkflowDetailsOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public TransferServerWorkflowDetailsOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putOnUpload(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload value) {
        software.amazon.jsii.Kernel.call(this, "putOnUpload", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetOnUpload() {
        software.amazon.jsii.Kernel.call(this, "resetOnUpload", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUploadOutputReference getOnUpload() {
        return software.amazon.jsii.Kernel.get(this, "onUpload", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUploadOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload getOnUploadInput() {
        return software.amazon.jsii.Kernel.get(this, "onUploadInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetails getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetails value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/transfer_server/TransferServerWorkflowDetailsOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.transfer_server;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:12.015Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.transferServer.TransferServerWorkflowDetailsOutputReference")
public class TransferServerWorkflowDetailsOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected TransferServerWorkflowDetailsOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TransferServerWorkflowDetailsOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public TransferServerWorkflowDetailsOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putOnPartialUpload(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload value) {
        software.amazon.jsii.Kernel.call(this, "putOnPartialUpload", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putOnUpload(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload value) {
        software.amazon.jsii.Kernel.call(this, "putOnUpload", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetOnPartialUpload() {
        software.amazon.jsii.Kernel.call(this, "resetOnPartialUpload", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetOnUpload() {
        software.amazon.jsii.Kernel.call(this, "resetOnUpload", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUploadOutputReference getOnPartialUpload() {
        return software.amazon.jsii.Kernel.get(this, "onPartialUpload", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUploadOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUploadOutputReference getOnUpload() {
        return software.amazon.jsii.Kernel.get(this, "onUpload", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUploadOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload getOnPartialUploadInput() {
        return software.amazon.jsii.Kernel.get(this, "onPartialUploadInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload getOnUploadInput() {
        return software.amazon.jsii.Kernel.get(this, "onUploadInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetails getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetails.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetails value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
